@@ -22,19 +22,7 @@ class ConferenceModel : public QAbstractListModel
     Q_PROPERTY(bool busyDownlading READ busyDownlading NOTIFY busyDownladingChanged)
 
 public:
-    enum Roles {
-        ConferenceId = Qt::UserRole + 1,
-        ConferenceName,
-        ConferenceDescription,
-        ConferenceIcalUrl,
-        ConferenceDays,
-        ConferenceVenueImageUrl,
-        ConferenceVenueLongitude,
-        ConferenceVenueLatitude,
-        ConferenceVenueOsmUrl,
-        ConferenceTimeZone,
-        PastUpcoming
-    };
+    enum Roles { ConferenceId = Qt::UserRole + 1, ConferenceName, ConferenceDescription, PastUpcoming };
 
     explicit ConferenceModel(QObject *parent = nullptr);
 
@@ -59,7 +47,7 @@ private:
     QString pastOrUpcoming(const int index) const;
 
     ConferenceController *m_controller;
-    QVector<Conference *> m_conferences;
+    QList<Conference> m_conferences;
     bool m_busy_downloading;
 };
 #endif
